import { UpdateMethod } from "./DataHandlingUtil";
import { MajorVersionIdentifier, SchemaIdentifier } from "./main";
import { DPMRecord } from "./PackageUtil";
import { Parameter, ParameterAnswer } from "./Parameter";
import { SinkState } from "./SinkState";
export interface SchemaRepositoryStreamIdentifier extends SchemaIdentifier {
    sourceType: string;
    sourceSlug: string;
    streamSetSlug: string;
    streamSlug: string;
}
export interface BatchRepositoryIdentifier extends SchemaRepositoryStreamIdentifier {
    batch: number;
}
export interface DataRecordContext {
    offset: number;
    record: DPMRecord;
}
export declare enum SocketEvent {
    READY = "ready",
    OPEN_FETCH_CHANNEL = "openFetchChannel",
    START_DATA_UPLOAD = "startDataUpload",
    SET_STREAM_ACTIVE_BATCHES = "setStreamActiveBatchesRequest",
    SCHEMA_INFO_REQUEST = "schemaInfoRequest",
    PACKAGE_VERSION_SINK_STATE_REQUEST = "packageVersionSinkStateRequest",
    START_PACKAGE_UPDATE = "startPackageUpdate",
    START_PACKAGE = "startPackage"
}
export declare enum SocketError {
    NOT_AUTHORIZED = "notAuthorized",
    NOT_FOUND = "notFound",
    NOT_VALID = "notValid",
    STREAM_LOCKED = "streamLocked",
    SERVER_ERROR = "serverError",
    NOT_STARTED = "streamProcessNotStarted"
}
export declare enum SocketResponseType {
    ERROR = "error",
    SCHEMA_INFO_RESPONSE = "schemaInfoResponse",
    START_DATA_UPLOAD_RESPONSE = "startDataUploadResponse",
    SET_STREAM_ACTIVE_BATCHES = "setStreamActiveBatchesResponse",
    OPEN_FETCH_CHANNEL_RESPONSE = "openFetchChannelResponse",
    PACKAGE_VERSION_SINK_STATE_RESPONSE = "packageVersionSinkStateResponse",
    START_PACKAGE_UPDATE_RESPONSE = "startPackageUpdateResponse",
    START_PACKAGE_RESPONSE = "startPackageResponse"
}
export interface Request {
    requestType: SocketEvent;
}
export interface Response {
    responseType: SocketResponseType;
}
export declare type StartJobRequest = Request;
export interface StartJobResponse extends Response {
    channelName: string;
}
export declare class ErrorResponse implements Response {
    message: string;
    errorType: SocketError;
    responseType: SocketResponseType;
    constructor(message: string, errorType: SocketError);
}
export declare class PackageSinkStateRequest implements Request {
    identifier: MajorVersionIdentifier;
    requestType: SocketEvent;
    constructor(identifier: MajorVersionIdentifier);
}
export declare class PackageSinkStateResponse implements Response {
    identifier: MajorVersionIdentifier;
    state: SinkState;
    responseType: SocketResponseType;
    constructor(identifier: MajorVersionIdentifier, state: SinkState);
}
export declare class PackageStreamsRequest implements Request {
    identifier: MajorVersionIdentifier;
    requestType: SocketEvent;
    constructor(identifier: MajorVersionIdentifier);
}
export interface BatchInfo {
    batchIdentifier: BatchRepositoryIdentifier;
    highestOffset: number;
    updatedAt: Date;
    updateMethod: UpdateMethod;
}
export interface BatchesBySchema {
    [schema: string]: BatchInfo[];
}
export declare class PackageStreamsResponse implements Response {
    identifier: MajorVersionIdentifier;
    batchesBySchema: BatchesBySchema;
    responseType: SocketResponseType;
    constructor(identifier: MajorVersionIdentifier, batchesBySchema: BatchesBySchema);
}
export declare class SetStreamActiveBatchesRequest implements Request {
    batchIdentifiers: BatchRepositoryIdentifier[];
    requestType: SocketEvent;
    constructor(batchIdentifiers: BatchRepositoryIdentifier[]);
}
export declare class SetStreamActiveBatchesResponse implements Response {
    batchIdentifiers: BatchRepositoryIdentifier[];
    responseType: SocketResponseType;
    constructor(batchIdentifiers: BatchRepositoryIdentifier[]);
}
export declare enum UploadRequestType {
    UPLOAD_DATA = "uploadData",
    UPLOAD_STOP = "uploadStop"
}
export declare enum UploadResponseType {
    UPLOAD_RESPONSE = "uploadResponse",
    UPLOAD_STOP_RESPONSE = "uploadStopResponse"
}
export interface UploadRequest {
    requestType: UploadRequestType;
}
export interface UploadResponse {
    responseType: UploadResponseType;
}
export declare class StartUploadRequest implements StartJobRequest {
    schemaStreamIdentifier: SchemaRepositoryStreamIdentifier;
    newBatch: boolean;
    updateMethod: UpdateMethod;
    requestType: SocketEvent;
    constructor(schemaStreamIdentifier: SchemaRepositoryStreamIdentifier, newBatch: boolean, updateMethod: UpdateMethod);
}
export declare class StartUploadResponse implements StartJobResponse {
    channelName: string;
    batchIdentifier: BatchRepositoryIdentifier;
    responseType: SocketResponseType;
    constructor(channelName: string, batchIdentifier: BatchRepositoryIdentifier);
}
export declare class UploadDataRequest implements UploadRequest {
    records: DataRecordContext[];
    requestType: UploadRequestType;
    constructor(records: DataRecordContext[]);
}
export declare class UploadDataResponse implements UploadResponse {
    responseType: UploadResponseType;
}
export declare class UploadStopRequest implements UploadRequest {
    requestType: UploadRequestType;
}
export declare class UploadStopResponse implements UploadResponse {
    responseType: UploadResponseType;
}
export declare class OpenFetchChannelRequest implements StartJobRequest {
    batchIdentifier: BatchRepositoryIdentifier;
    requestType: SocketEvent;
    constructor(batchIdentifier: BatchRepositoryIdentifier);
}
export declare class OpenFetchChannelResponse implements StartJobResponse {
    channelName: string;
    batchIdentifier: BatchRepositoryIdentifier;
    responseType: SocketResponseType;
    constructor(channelName: string, batchIdentifier: BatchRepositoryIdentifier);
}
export declare enum SocketFetchEvent {
    FETCH_DATA_ACKNOWLEDGE = "fetchDataAcknowledge",
    FETCH_DATA_END = "fetchDataEnd"
}
export declare enum FetchRequestType {
    START = "fetchDataStart",
    DATA = "data",
    STOP = "fetchDataStop"
}
export declare enum FetchResponseType {
    START_ACKNOWLEDGE = "startAcknowledge",
    DATA_ACKNOWLEDGE = "dataAcknowledge",
    STOP_ACKNOWLEDGE = "fetchDataStopAcknowledge"
}
export interface FetchRequest {
    requestType: FetchRequestType;
}
export interface FetchResponse {
    responseType: FetchResponseType;
}
export declare class StartFetchRequest implements FetchRequest {
    offset: number;
    requestType: FetchRequestType;
    constructor(offset: number);
}
export declare class StartFetchResponse implements FetchResponse {
    responseType: FetchResponseType;
}
export declare class DataSend implements FetchRequest {
    records: DataRecordContext[];
    requestType: FetchRequestType;
    constructor(records: DataRecordContext[]);
}
export declare class DataAcknowledge implements FetchResponse {
    responseType: FetchResponseType;
}
export declare class DataStop implements FetchRequest {
    requestType: FetchRequestType;
}
export declare class DataStopAcknowledge implements FetchResponse {
    responseType: FetchResponseType;
}
export declare class StartPackageRequest implements StartJobRequest {
    requestType: SocketEvent;
    catalogSlug: string;
    packageSlug: string;
    packageTitle: string;
    packageDescription: string;
    defaults: boolean;
    constructor(catalogSlug: string, packageSlug: string, packageTitle: string, packageDescription: string, defaults: boolean);
}
export declare class StartPackageResponse implements StartJobResponse {
    responseType: SocketResponseType;
    channelName: string;
    constructor(channelName: string);
}
export declare class StartPackageUpdateRequest implements StartJobRequest {
    packageIdentifier: {
        catalogSlug: string;
        packageSlug: string;
    };
    defaults: boolean;
    requestType: SocketEvent;
    constructor(packageIdentifier: {
        catalogSlug: string;
        packageSlug: string;
    }, defaults: boolean);
}
export declare class StartPackageUpdateResponse implements StartJobResponse {
    responseType: SocketResponseType;
    channelName: string;
    constructor(channelName: string);
}
export declare enum JobRequestType {
    START_JOB = "startJob",
    PRINT = "print",
    PROMPT = "prompt",
    START_TASK = "startTask",
    TASK_UPDATE = "taskUpdate",
    END_TASK = "endTask",
    SET_CURRENT_STEP = "setCurrentStep",
    SET_STEPS = "setSteps",
    EXIT = "exit",
    ERROR = "error"
}
export declare type JobMessageType = "NONE" | "ERROR" | "WARN" | "INFO" | "DEBUG" | "SUCCESS" | "FAIL" | "UPDATE" | "START";
export declare type TaskStatus = "RUNNING" | "ERROR" | "SUCCESS";
export declare class JobResult<T> {
    exitCode: number;
    errorMessage?: string;
    result?: T | undefined;
}
export declare class JobMessageRequest {
    constructor(requestType: JobRequestType);
    requestType: JobRequestType;
    message?: string;
    messageType?: JobMessageType;
    jobResult?: JobResult<unknown>;
    exitResult?: unknown;
    taskStatus?: TaskStatus;
    taskId?: string;
    steps?: string[];
    prompts?: Parameter[];
}
export declare class JobMessageResponse<T extends string = string> {
    constructor(responseType: JobRequestType);
    message?: string;
    responseType: JobRequestType;
    answers?: ParameterAnswer<T>;
}
